      program newton

        implicit none

c   Use a Newton iteration to solve a polynomial equation
c
c    x     -    current approximation to the solution
c    f     -    polynomial function
c    df    -    derivative of f with respect to x
c    xo    -    previous guess for solution
c    eps   -    convergence criterion
c    dx    -    change in solution approximation
c    it    -    number of iterations
c    itmax -    maximum number of iterations
      
        real 
        integer 

c     Now start executable fortran statements

        x= 
        do while ()
          x=
        end do

      end

c ******************************************************************************************

      subroutine derivate(x,f,df)

c   Evaluate the function f(x)=x**3+x-10
c   also return the derivative of the function
                                             
        implicit none
        real 

      return
      end
